@@ -6,12 +6,15 @@ def create_repo(repo_name, token=None, provider='github'):
   if 'github' in provider:
     g = Github(token)
     user = g.get_user()
-    user.create_repo(repo_name)
+    repo = user.create_repo(repo_name)
+    return repo
 
 def delete_repo(repo_name, token=None, provider='github'):
   if not token:
     print('Token required')
   if 'github' in provider:
     g = Github(token)
-    user = g.get_user()
-    user.create_repo(repo_name)
+
+    repo = g.get_repo(f"{g.get_user().login}/{repo_name}")
+    repo.delete()
+    print(f"Repo {repo_name} deleted")
